/*
  +------------------------------+
  |                              |
  |   Time measuring function.   |
  |                              |
  +------------------------------+
*/
#include <sys\timeb.h>
#include <stdio.h>
#include "timer.h"

static ztime_t offset_time;

//
// Call this once to set trimmer variable, offset_time.
//
void init_time()
{
    timeb timebuf;
    ftime( &timebuf);
    offset_time = timebuf.time;
}

//
// Returns wallclock time in milliseconds.  Has only
// about 55 ms resolution on a PC.
//
ztime_t wallclock()
{
    timeb timebuf;
    ftime( &timebuf);
    return (timebuf.time - offset_time) * 1000 + timebuf.millitm;
}


//
// Make a time string from ztime_t difference in milliseconds.
//
char *timestr( ztime_t diftime)
{
    static char str[16];

    double seconds = (double)diftime * 0.001;
    if( seconds < 60.0 ) {
        int s = (int)seconds;
        int f = (int)(100 * (seconds - s));
        sprintf( str, "   %2d.%02d", s, f);
    } else if( seconds < 3600.0 ) {
        int m = (int)(seconds / 60.0);
        int s = (int)(seconds - m * 60.0);
        sprintf( str, "   %2d:%02d", m, s);
    } else {
        int h = (int)(seconds / 3600.0);
        seconds -= h * 3600.0;
        int m = (int)(seconds / 60.0);
        seconds -= m * 60.0;
        int s = (int)seconds;
        sprintf( str, "%2d:%02d:%02d", h, m, s);
    }
    return str;
}
